import { BaseCustomWebComponentConstructorAppend, css, html } from "@node-projects/base-custom-webcomponent";
import Chart from 'chart.js/auto/auto.js';
export class ChartJsWebcomponent extends BaseCustomWebComponentConstructorAppend {
    static style = css `
            :host {
                display: block;
                position: relative;
            }
            
            canvas {
                width: 100%;
                height: 100%;
                position: absolute;
            }`;
    static template = html `<canvas id="root"></canvas>`;
    static is = 'node-projects-chart-js';
    static properties = {
        data: Object,
        borderColor: String,
        backgroundColor: String
    };
    #data;
    get data() {
        return this.#data;
    }
    set data(value) {
        this.#data = value;
        if (this.#ready) {
            this.#renderChart();
        }
    }
    #borderColor;
    get borderColor() {
        return this.#borderColor;
    }
    set borderColor(value) {
        this.#borderColor = value;
        if (this.#ready) {
            this.#renderChart();
        }
    }
    #backgroundColor;
    get backgroundColor() {
        return this.#backgroundColor;
    }
    set backgroundColor(value) {
        this.#backgroundColor = value;
        if (this.#ready) {
            this.#renderChart();
        }
    }
    #root;
    #ready;
    #chart;
    constructor() {
        super();
        this._restoreCachedInititalValues();
        this.#root = this._getDomElement('root');
    }
    ready() {
        this._parseAttributesToProperties(true);
        this.#renderChart();
        this.#ready = true;
    }
    #renderChart() {
        let labels;
        let values;
        if (Array.isArray(this.#data[0])) {
            labels = this.#data.map(row => row[1]);
            values = this.#data.map(row => row[0]);
        }
        else {
            labels = this.#data.map(row => row.label);
            values = this.#data.map(row => row.value);
        }
        if (this.#chart)
            this.#chart.destroy();
        this.#chart = new Chart(this.#root, {
            type: 'line',
            data: {
                labels: labels,
                datasets: [
                    {
                        data: values,
                        fill: true,
                        borderColor: this.#borderColor,
                        backgroundColor: this.#backgroundColor
                    }
                ]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        display: false
                    }
                }
            }
        });
    }
}
customElements.define(ChartJsWebcomponent.is, ChartJsWebcomponent);
